@@ -8,8 +8,8 @@ from ground.core.hints import (Coordinate,
 from .polygon import centroid_components as polygon_centroid_components
 
 
-def centroid(point_cls: Type[Point],
-             polygons: Sequence[Polygon]) -> Point:
+def centroid(polygons: Sequence[Polygon],
+             point_cls: Type[Point]) -> Point:
     x_numerator, y_numerator, double_area = centroid_components(polygons)
     inverted_denominator = 1 / (3 * double_area)
     return point_cls(x_numerator * inverted_denominator,
