@@ -3,12 +3,12 @@ from typing import (Callable,
                     Sequence,
                     Type)
 
+from ground.core.hints import Point
 from ground.core.shewchuk import add_to_expansion
-from ground.hints import Point
 
 
-def centroid(point_cls: Type[Point],
-             points: Sequence[Point],
+def centroid(points: Sequence[Point],
+             point_cls: Type[Point],
              inverse: Callable[[int], Fraction] = Fraction(1).__truediv__
              ) -> Point:
     result_x = result_y = (0,)
