@@ -1,5 +1,5 @@
-from ground.hints import (Coordinate,
-                          Point)
+from ground.core.hints import (Coordinate,
+                               Point)
 
 
 def multiply(first_start: Point,
